OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Eenvoudige bestand viewer met diavertoning voor media bestanden",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Toon je laatste vakantie foto's en videos als in de film, toon een deel van je laatste boek direct uit uw nextcloud, kies de beste GIF uit jouw collectie dankzij de directe voorvertoning van je favoriete bestanden en nog veel meer!",
    "Error loading {name}" : "Fout bij laden van {name}",
    "Your browser does not support videos." : "Je browser ondersteunt geen videos.",
    "Open sidebar" : "Openen zijbalk",
    "Delete" : "Verwijderen",
    "There is no plugin available to display this file type" : "Er is geen plugin beschikbaar om dit bestandstype weer te geven",
    "View" : "Bekijken",
    "Your browser does not support the video tag." : "Je browser ondersteunt de video tag niet."
},
"nplurals=2; plural=(n != 1);");
